==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/ro.js <==
OC.L10N.register(
    "files_external",
    {
    "Personal" : "Personal",
    "System" : "Sistem",
    "Grant access" : "Permite accesul",
    "Error configuring OAuth1" : "Eroare la configurarea OAuth1",
    "Error configuring OAuth2" : "Eroare la configurarea OAuth2",
    "Generate keys" : "Generează chei",
    "Error generating key pair" : "Eroarea la generarea cheilor",
    "All users. Type to select user or group." : "Toți utilizatorii. Începe să scrii pentru a selecta un utilizator sau un grup.",
    "(group)" : "(grup)",
    "Admin defined" : "Administrator definit",
    "Saved" : "Salvat",
    "Save" : "Salvează",
    "Empty response from the server" : "Răspuns nul de la server",
    "There was an error with message: " : "A apărut o eroare cu mesajul:",
    "external-storage" : "Stocare externă",
    "Username" : "Nume utilizator",
    "Password" : "Parolă",
    "Credentials saved" : "Detalii de autentificare salvate",
    "Credentials saving failed" : "Salvarea detaliilor de autentificare a eșuat",
    "Credentials required" : "Detalii de autentificare necesare",
    "Insufficient data: %s" : "Date insuficiente: %s",
    "%s" : "%s",
    "Access key" : "Cheie de acces",
    "Secret key" : "Cheie secretă",
    "Builtin" : "Inclus",
    "None" : "Niciuna",
    "OAuth1" : "OAuth1",
    "App key" : "Cheie aplicație",
    "App secret" : "Secret aplicație",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID client",
    "Client secret" : "Secret client",
    "Tenant name" : "Nume titular",
    "Domain" : "Domeniu",
    "API key" : "Cheie API",
    "Username and password" : "Nume de utilizator și parolă",
    "RSA public key" : "Cheie publică RSA",
    "Public key" : "Cheie publică",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Nume mașină",
    "Port" : "Port",
    "Region" : "Regiune",
    "Enable SSL" : "Activează SSL",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Secure https://" : "https:// sigur",
    "FTP" : "FTP",
    "Host" : "Gazdă",
    "Secure ftps://" : "ftps:// sigur",
    "Local" : "Local",
    "Location" : "Locație",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP cu cheie secretă de autentificare",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Partajează",
    "SMB / CIFS using OC login" : "SMB / CIFS folosind autentificare OC",
    "Service name" : "Nume serviciu",
    "Name" : "Nume",
    "Storage type" : "Tip stocare",
    "Scope" : "Scop",
    "Enable encryption" : "Activează criptarea",
    "Enable previews" : "Activează previzualizările",
    "Enable sharing" : "Activează partajarea",
    "Check for changes" : "Verifică dacă au intervenit modificări",
    "Never" : "Niciodată",
    "Once every direct access" : "O dată la fiecare acces direct",
    "Folder name" : "Denumire director",
    "External storage" : "Stocare externă",
    "Authentication" : "Autentificare",
    "Configuration" : "Configurație",
    "Available for" : "Disponibil pentru",
    "Add storage" : "Adauga stocare",
    "Advanced settings" : "Setări avansate",
    "Delete" : "Șterge",
    "Allow users to mount the following external storage" : "Permite utilizatorilor să monteze următoarea unitate de stocare",
    "OpenStack" : "OpenStack"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/ro.js <==
OC.L10N.register(
    "files_external",
    {
    "Personal" : "Personal",
    "System" : "Sistem",
    "Grant access" : "Permite accesul",
    "Error configuring OAuth1" : "Eroare la configurarea OAuth1",
    "Error configuring OAuth2" : "Eroare la configurarea OAuth2",
    "Generate keys" : "Generează chei",
    "Error generating key pair" : "Eroarea la generarea cheilor",
    "All users. Type to select user or group." : "Toți utilizatorii. Începe să scrii pentru a selecta un utilizator sau un grup.",
    "(group)" : "(grup)",
    "Admin defined" : "Administrator definit",
    "Saved" : "Salvat",
    "Save" : "Salvează",
    "Empty response from the server" : "Răspuns nul de la server",
    "There was an error with message: " : "A apărut o eroare cu mesajul:",
    "external-storage" : "Stocare externă",
    "Username" : "Nume utilizator",
    "Password" : "Parolă",
    "Credentials saved" : "Detalii de autentificare salvate",
    "Credentials saving failed" : "Salvarea detaliilor de autentificare a eșuat",
    "Credentials required" : "Detalii de autentificare necesare",
    "Insufficient data: %s" : "Date insuficiente: %s",
    "%s" : "%s",
    "Access key" : "Cheie de acces",
    "Secret key" : "Cheie secretă",
    "Builtin" : "Inclus",
    "None" : "Niciuna",
    "OAuth1" : "OAuth1",
    "App key" : "Cheie aplicație",
    "App secret" : "Secret aplicație",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID client",
    "Client secret" : "Secret client",
    "Tenant name" : "Nume titular",
    "Domain" : "Domeniu",
    "API key" : "Cheie API",
    "Username and password" : "Nume de utilizator și parolă",
    "RSA public key" : "Cheie publică RSA",
    "Public key" : "Cheie publică",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Nume mașină",
    "Port" : "Port",
    "Region" : "Regiune",
    "Enable SSL" : "Activează SSL",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Secure https://" : "https:// sigur",
    "FTP" : "FTP",
    "Host" : "Gazdă",
    "Secure ftps://" : "ftps:// sigur",
    "Local" : "Local",
    "Location" : "Locație",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP cu cheie secretă de autentificare",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Partajează",
    "SMB / CIFS using OC login" : "SMB / CIFS folosind autentificare OC",
    "Service name" : "Nume serviciu",
    "Name" : "Nume",
    "Storage type" : "Tip stocare",
    "Scope" : "Scop",
    "Enable encryption" : "Activează criptarea",
    "Enable previews" : "Activează previzualizările",
    "Enable sharing" : "Activează partajarea",
    "Check for changes" : "Verifică dacă au intervenit modificări",
    "Never" : "Niciodată",
    "Once every direct access" : "O dată la fiecare acces direct",
    "Folder name" : "Denumire director",
    "External storage" : "Stocare externă",
    "Authentication" : "Autentificare",
    "Configuration" : "Configurație",
    "Available for" : "Disponibil pentru",
    "Add storage" : "Adauga stocare",
    "Advanced settings" : "Setări avansate",
    "Delete" : "Șterge",
    "OpenStack" : "OpenStack",
    "Allow users to mount the following external storage" : "Permite utilizatorilor să monteze următoarea unitate de stocare"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
